@@ -234,4 +234,39 @@ compnames <- function(object, comps, explvar = FALSE, ...) {
     labs <- paste(labs, " (", format(evar, digits = 2, trim = TRUE),
                   " %)", sep = "")
   return(labs)
-}
\ No newline at end of file
+}
+
+#' Extracting the Extended Model Frame from a Formula or Fit
+#' 
+#' @description
+#' This function attempts to apply \code{\link{model.frame}} and extend the 
+#' result with columns of interactions. 
+#'
+#' @param formula a model formula or terms object or an R object.
+#' @param data a data.frame, list or environment (see \code{\link{model.frame}}).
+#' @param ... further arguments to pass to \code{\link{model.frame}}.
+#' @param sep separator in contraction of names for interactions (default = ".").
+#'
+#' @return A \code{\link{data.frame}} that includes everything a \code{\link{model.frame}}
+#' does plus interaction terms.
+#' @export
+#'
+#' @examples
+#' dat <- data.frame(Y = c(1,2,3,4,5,6), 
+#'                   X = factor(LETTERS[c(1,1,2,2,3,3)]), 
+#'                   W = factor(letters[c(1,2,1,2,1,2)]))
+#' extended.model.frame(Y ~ X*W, dat)
+extended.model.frame <- function(formula, data, ..., sep = "."){
+  # Model frame and terms factors (remove response row if presents)
+  fac <- attr(terms(mf <- model.frame(formula, data, ...)), "factors")
+  fac <- fac[rowSums(fac)>0,, drop=FALSE]
+  # Create all included interactions
+  int <- lapply(1:ncol(fac), function(i) interaction(data[rownames(fac)[fac[,i]==1]], sep = sep))
+  # Convert to data.frame and add interactions to original model.frame
+  names(int) <- colnames(fac)
+  modFra <- as.data.frame(int, check.names = FALSE)
+  for(i in setdiff(colnames(modFra), colnames(mf)))
+    mf[[i]] <- modFra[[i]]
+  mf
+}
+
